OC.L10N.register(
    "groupfolders",
    {
    "Group" : "Groep",
    "Create" : "Skep",
    "Delete" : "Skrap",
    "Share" : "Deel",
    "You" : "U",
    "Unlimited" : "Onbeperkte",
    "Folder name" : "Vouernaam",
    "Quota" : "Kwota",
    "Previous" : "Vorige",
    "User" : "Gebruiker",
    "None" : "Geen",
    "{size} used" : "{size} gebruik"
},
"nplurals=2; plural=(n != 1);");
